<?php
/*
Plugin Name: WordPress HQ
Plugin URI:  http://link to your plugin homepage
Description: Locks down WordPress for a cleaner interface and less chance of breaking stuff. Simplify updates, dashboard, and make it easier to reach out to us.
Version:     1.01
Author:      Kira Davis
Author URI:  http://link to your website
License:     GPL2 etc
License URI: http://link to your plugin license
*/

remove_role('site_owner');
$result = add_role(
    'site_owner',
    __( 'Site Manager', 'testdomain' ),
    array(
      // General
      'read'  => true,
      'create_posts' => true,
      'edit_posts'  => true,
      'edit_others_posts' => true,
      'publish_posts'     => true,
      'manage_categories' => true
    )
);

/* Only run code if in the admin area */
add_action('init', 'admin_only');

function admin_only() {

    if( !is_admin() )
        return;

    // If user is given site owner role, give them admin too.
    // This is because some plugins will hide the dashboard from non-admins
    function action_set_user_role( $this_id, $role, $old_roles ) {
      if ( $role == 'site_owner' ) {
          $user = new WP_User( $this_id );
          $user->add_role( 'administrator' );
      }
    };

    // add the action
    add_action( 'set_user_role', 'action_set_user_role', 10, 3 );

    $menusHidden = true;
    $noticesHidden = true;

    wp_enqueue_style( 'style', plugin_dir_url(__FILE__) . 'style.css' );  // include CSS file

    /* Hide notices/updates/errors */
    if($noticesHidden) {
        //if($user->roles[0] === 'artist') {
          add_action('admin_enqueue_scripts', 'hidenotice_admin_theme_style');
          add_action('login_enqueue_scripts', 'hidenotice_admin_theme_style');
        //}
    }

    function hidenotice_admin_theme_style() {
      if (is_admin()) {
        echo '<style>.notice, .update-nag, .updated, .error, .is-dismissible, .jitm-banner, .woocommerce-layout .is-alert-update, .wrap div.fs-notice.updated, .wrap div.fs-notice.success, .wrap div.fs-notice.promotion { display: none !important; }</style>';
      }
    }

    /* Add widgets */
    function dashboard_thrive_client() { include('thriveclient.php'); }
    function dashboard_manage_website() { include('managewebsite.php'); }
    function dashboard_request_updates() { include('requestupdates.php'); }
    function dashboard_accessibility() { include('websiteaccessibility.php'); }
    function dashboard_seo() { include('seoandcontent.php'); }
    function dashboard_advanced() { include('advancedoptions.php'); }
    function dashboard_quick_links() { include('quicklinks.php'); }
    function dashboard_contact() { include('contactthrive.php'); }
    function dashboard_checklist() { include('websitechecklist.php'); }

    function gpr_wp_dashboard_setup() {
		$user = wp_get_current_user();

		// If not a site owner, admin, or editor: return & don't change dashboard
		if ( !in_array( 'site_owner', (array) $user->roles ) && !in_array( 'administrator', (array) $user->roles ) && !in_array( 'editor', (array) $user->roles )) {
			return;
		}

        // Remove Welcome panel.
        remove_action( 'welcome_panel', 'wp_welcome_panel' );

        // Remove all Dashboard widgets.
        global $wp_meta_boxes;
        unset( $wp_meta_boxes['dashboard'] );

        //==========================================
        // Side widgets
        //==========================================
        // Add Quick Links widget.
        add_meta_box( 'dashboard_quick_links',
            __( 'Quick Links', 'quick-links' ),
            __NAMESPACE__ . 'dashboard_quick_links',
            'dashboard',
            'side',  // $context: 'advanced', 'normal', 'side', 'column3', 'column4'
            'high'     // $priority: 'high', 'core', 'default', 'low'
        );

        // Add Contact Thrive widget
        add_meta_box( 'dashboard_contact',
            __( 'Contact Thrive Web Designs', 'contact-thrive' ),
            __NAMESPACE__ . 'dashboard_contact',
            'dashboard',
            'side',  // $context: 'advanced', 'normal', 'side', 'column3', 'column4'
            'high'     // $priority: 'high', 'core', 'default', 'low'
        );

        //===================================
        // Normal widgets
        //===================================
        wp_add_dashboard_widget( 'gpr_wp_dashboard_test', __( 'As a Thrive client...' ),'dashboard_thrive_client');
        wp_add_dashboard_widget( 'gpr_wp_dashboard_test2', __( 'Manage Your Website' ),'dashboard_manage_website');
        wp_add_dashboard_widget( 'gpr_wp_dashboard_test3', __( 'Request Updates' ),'dashboard_request_updates');
        wp_add_dashboard_widget( 'gpr_wp_dashboard_test4', __( 'Website Accessibility' ),'dashboard_accessibility');
        wp_add_dashboard_widget( 'gpr_wp_dashboard_test5', __( 'SEO & Content' ),'dashboard_seo');


        if ( !in_array( 'site_owner', (array) $user->roles ) && in_array( 'administrator', (array) $user->roles ) ) { // ONLY DO THIS FOR ADMIN (not site manager)
		  wp_add_dashboard_widget( 'gpr_wp_dashboard_test6', __( 'Advanced Options' ),'dashboard_advanced');
          wp_add_dashboard_widget( 'gpr_wp_dashboard_test9', __( 'Website Checklist' ),'dashboard_checklist');
        }
    }
    add_action('wp_dashboard_setup', 'gpr_wp_dashboard_setup');

    // Enqueue Scripts
      wp_enqueue_script('jquery');
      wp_enqueue_script('my-custom-script', plugin_dir_url( __FILE__ ) . 'script.js', array('jquery'), null, true);


    function get_latest_post_link(){
        global $post;
        $placeholder = $post;
        $args = array(
            'numberposts'     => 1,
            'offset'          => 0,
            'orderby'         => 'post_date',
            'order'           => 'DESC',
            'post_status'     => 'publish' );
        $sorted_posts = get_posts( $args );
        $permalink = get_permalink($sorted_posts[0]->ID);
        $title = $sorted_posts[0]->post_title;
        $post = $placeholder;
        /* $latest_link_html = '<a href="'.$permalink.'" target="_blank">View Latest Post ('.$title.')</a>'; */
        $latest_link_html = '<a href="'.$permalink.'" target="_blank">View Latest Post</a>';
        return $permalink;
    }

    function get_latest_page_link(){
        $pages = get_pages( array( 'sort_column' => 'post_date', 'sort_order' => 'desc' ) );

        if ($pages) {
          $newestPage = $pages[0];
          $permalink = get_page_link( $newestPage->ID );
          $title = $newestPage->post_title;
          $latest_link_html = '<a href="'.$permalink.'" target="_blank">View Latest Page</a>';
          /* $latest_link_html = '<a href="'.$permalink.'" target="_blank">View Latest Page ('.$title.')</a>'; */
          return $permalink;
        } else {
          return 'No pages.';
        }
    }

    // function remove_dashboard_widgets() {
    //     global $wp_meta_boxes;
    //
    //     //var_dump($wp_meta_boxes);
    //
    //     /** Default widgets */
    //     unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_quick_press']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_incoming_links']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_right_now']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_plugins']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_recent_drafts']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_recent_comments']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_site_health']);
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['dashboard_activity']);
    //     unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);
    //     unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_secondary']);
    //
    //     /** 3rd Party widgets */
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['example_dashboard_widget']); // postman
    //     unset($wp_meta_boxes['dashboard']['normal']['core']['rg_forms_dashboard']); // gravity forms
    // }
    //
    // add_action('wp_dashboard_setup', 'remove_dashboard_widgets' );

    /**
    * Registers a text field setting for Wordpress 4.7 and higher.
    **/
    function register_my_setting() {
        $args = array(
                'type' => 'string',
                'sanitize_callback' => 'sanitize_text_field',
                'default' => NULL,
                );
        register_setting( 'my_options_group', 'my_option_name', $args );
    }
    add_action( 'admin_init', 'register_my_setting' );


    /** Remove menu items */
    if (!function_exists('debug_admin_menus')):
    function debug_admin_menus() {
        global $submenu, $menu, $pagenow;
        $user = wp_get_current_user();
        if ( in_array( 'site_owner', (array) $user->roles ) ) { // ONLY DO THIS FOR SITE OWNER
            //echo '<pre>'; print_r( $menu ); echo '</pre>'; // TOP LEVEL MENUS
            //echo '<pre>'; print_r( $submenu ); echo '</pre>'; // SUBMENUS
            for ($i = 0; $i <= count($menu); $i++) {
              if (
                $menu[$i][2] == 'index.php' ||                // Dashboard
                $menu[$i][2] == 'edit.php' ||                 // Posts
                $menu[$i][2] == 'upload.php' ||               // Media
                $menu[$i][2] == 'edit.php?post_type=page' ||  // Pages
                $menu[$i][2] == 'edit-comments.php' ||        // Comments
                $menu[$i][2] == 'tablepress' ||               // Tablepress
                $menu[$i][2] == 'cfdb7-list.php' ||           // Contact
                $menu[$i][2] == 'gf_edit_forms' ||            // Forms
                $menu[$i][2] == 'themes.php' ||               // Appearance
                $menu[$i][2] == 'woocommerce' ||              // WooCommerce
                $menu[$i][2] == 'edit.php?post_type=product'  // Products
                // TODO: Acabado Settings
                // TODO: Acabado Manager
                // TODO: REFER
              ) {
                // do nothing
              } else {
                remove_menu_page( $menu[$i][2] );
              }
            }
            remove_menu_page( 'postman' );                    //Post SMTP
            remove_menu_page( 'ultimate_affiliates_pro' );    //Ultimate Affiliate Pro
            remove_menu_page( 'about-ultimate' );             //The7 Ultimate
            remove_menu_page( 'vc-general' );                 //The7 WPBakery Page Builder
            remove_menu_page( 'wpseo_dashboard' );            //Yoast
            remove_menu_page( 'revslider' );                  //Slider Revolution
            remove_menu_page( 'plugins.php' );                //Plugins
            remove_menu_page( 'users.php' );                  //Users
            remove_menu_page( 'tools.php' );                  //Tools
            remove_menu_page( 'options-general.php' );        //Settings
            remove_menu_page( 'WP-Optimize' );                // WP Optimize
            remove_menu_page( 'itsec' );                      // iThemes Security
        }
    }
    add_action( 'admin_init', 'debug_admin_menus' );
    endif;

}

add_action( 'admin_head', 'q167372_dash_name' );
function q167372_dash_name(  ){
    if ( $GLOBALS['pagenow'] != 'index.php' ){
        return;
    }
	// Only change footer if we're on the main Dashboard page
	$screen = get_current_screen();

	if ($screen -> id == "dashboard") {
		add_filter('admin_footer_text', 'remove_footer_admin');
		add_filter('update_footer', 'remove_footer_version');
	}
    $GLOBALS['title'] =  __( 'WordPress HQ' );
}

// Change WordPress dashboard footer (left side)
function remove_footer_admin () {
    echo 'Thank you for building your business with <a href="https://www.thrivewebdesigns.com/" target="_blank">Thrive Web Designs</a>.';
}
// Change WordPress dashboard footer (right side)
function remove_footer_version () {
    echo '<a href="https://bitbucket.org/thriveweb/wordpress-hq/src/master/" target="_blank">Thrive WordPress HQ v1.0.1 </a>.';
}

function scratchcode_run_code_one_time() {
    if ( !get_option('customlinks_opt') ):

      include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

      $default_arr = array (
        'Create New Post'   => '/wp-admin/post-new.php',
        'Create New Page'   => '/wp-admin/post-new.php?post_type=page',
        'Upload Media'      => '/wp-admin/media-new.php',
        'View Latest Post'  => get_latest_post_link(),
        'View Latest Page'  => get_latest_page_link(),
        'View Comments'     => '/wp-admin/edit-comments.php'
      );

      $woocom_arr = array (
        'WooCommerce Orders' => '/wp-admin/edit.php?post_type=shop_order'
      );

      // Check if WooCommerce is active
      if (
          in_array(
            'woocommerce/woocommerce.php',
            apply_filters( 'active_plugins', get_option( 'active_plugins' ) )
          )
      ) {
          $default_arr = array_merge($default_arr, $woocom_arr);
      }

  		// IDK, it doesn't work with just add_ if you've deleted all custom links. Both works for some reason.
  		add_option( 'customlinks_opt', $default_arr, 1 );
  		update_option( 'customlinks_opt', $default_arr, 1 );

    endif;
}
add_action( 'init', 'scratchcode_run_code_one_time' );

// This would normally be enqueued as a file, but for the sake of ease we will just print to the footer
function add_this_script_footer(){ ?>

<!-- <script>
jQuery(document).ready(function($) {

    // This is the variable we are passing via AJAX
    var lis = new Array();

    // Iterate through the <li> items
    jQuery("#quick-links-list").children("a").each(function()
    {
        lis.push(jQuery(this).text());
    });
    //alert(lis);
    var fruit = 'Banana';

    // This does the ajax request (The Call).
    $.ajax({
        url: ajaxurl, // Since WP 2.8 ajaxurl is always defined and points to admin-ajax.php
        data: {
            'action':'example_ajax_request', // This is our PHP function below
            'fruit' : lis // This is the variable we are sending via AJAX
        },
        success:function(data) {
    // This outputs the result of the ajax request (The Callback)
            window.alert(data);
        },
        error: function(errorThrown){
            window.alert(errorThrown);
        }
    });

});
</script> -->
<?php }

add_action('in_admin_footer', 'add_this_script_footer');

function example_ajax_request() {

    // The $_REQUEST contains all the data sent via AJAX from the Javascript call
    if ( isset($_REQUEST) ) {

        $text = $_REQUEST['text'];
        $links = $_REQUEST['links'];

        $c = array_combine($text, $links);
        //print_r($c);
        update_option( 'customlinks_opt', $c );
    }

    // Always die in functions echoing AJAX content
   die();
}

// This bit is a special action hook that works with the WordPress AJAX functionality.
add_action( 'wp_ajax_example_ajax_request', 'example_ajax_request' );

?>
